package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenStaffMorningCheck;
import com.bonus.canteen.core.kitchen.service.IKitchenStaffMorningCheckService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房员工晨检记录Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房员工晨检记录接口")
@RestController
@RequestMapping("/kitchen_staff_morning_check")
public class KitchenStaffMorningCheckController extends BaseController {
    @Autowired
    private IKitchenStaffMorningCheckService kitchenStaffMorningCheckService;

    /**
     * 查询厨房员工晨检记录列表
     */
    @ApiOperation(value = "查询厨房员工晨检记录列表")
    //@RequiresPermissions("kitchen:check:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenStaffMorningCheck kitchenStaffMorningCheck) {
        startPage();
        List<KitchenStaffMorningCheck> list = kitchenStaffMorningCheckService.selectKitchenStaffMorningCheckList(kitchenStaffMorningCheck);
        return getDataTable(list);
    }

    /**
     * 导出厨房员工晨检记录列表
     */
    @ApiOperation(value = "导出厨房员工晨检记录列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:check:export")
    @SysLog(title = "厨房员工晨检记录", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房员工晨检记录")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenStaffMorningCheck kitchenStaffMorningCheck) {
        List<KitchenStaffMorningCheck> list = kitchenStaffMorningCheckService.selectKitchenStaffMorningCheckList(kitchenStaffMorningCheck);
        ExcelUtil<KitchenStaffMorningCheck> util = new ExcelUtil<KitchenStaffMorningCheck>(KitchenStaffMorningCheck.class);
        util.exportExcel(response, list, "厨房员工晨检记录数据");
    }

    /**
     * 获取厨房员工晨检记录详细信息
     */
    @ApiOperation(value = "获取厨房员工晨检记录详细信息")
    //@RequiresPermissions("kitchen:check:query")
    @GetMapping(value = "/{checkId}")
    public AjaxResult getInfo(@PathVariable("checkId") Long checkId) {
        return success(kitchenStaffMorningCheckService.selectKitchenStaffMorningCheckByCheckId(checkId));
    }

    /**
     * 新增厨房员工晨检记录
     */
    @ApiOperation(value = "新增厨房员工晨检记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:check:add")
    @SysLog(title = "厨房员工晨检记录", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房员工晨检记录")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenStaffMorningCheck kitchenStaffMorningCheck) {
        try {
            return toAjax(kitchenStaffMorningCheckService.insertKitchenStaffMorningCheck(kitchenStaffMorningCheck));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房员工晨检记录
     */
    @ApiOperation(value = "修改厨房员工晨检记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:check:edit")
    @SysLog(title = "厨房员工晨检记录", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房员工晨检记录")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenStaffMorningCheck kitchenStaffMorningCheck) {
        try {
            return toAjax(kitchenStaffMorningCheckService.updateKitchenStaffMorningCheck(kitchenStaffMorningCheck));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房员工晨检记录
     */
    @ApiOperation(value = "删除厨房员工晨检记录")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:check:remove")
    @SysLog(title = "厨房员工晨检记录", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房员工晨检记录")
	@PostMapping("/del/{checkIds}")
    public AjaxResult remove(@PathVariable Long[] checkIds) {
        return toAjax(kitchenStaffMorningCheckService.deleteKitchenStaffMorningCheckByCheckIds(checkIds));
    }
}
